/*============================================================================
	File: Checkpoints.sql 

	Summary: This script shows checkpoint tracing using trace flags
				and the transaction log
	
------------------------------------------------------------------------------
	Copyright (C) 2011 Paul S. Randal, SQLskills.com
	All rights reserved. 

	For more scripts and sample code, check out
		http://www.sqlskills.com/ 

	You may alter this code for your own *non-commercial* purposes. You may
	republish altered code as long as you give due credit. 

	THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF
	ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED
	TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
	PARTICULAR PURPOSE.
============================================================================*/ 

USE MASTER;
GO

IF DATABASEPROPERTYEX ('CheckpointTest', 'Version') > 0
	DROP DATABASE CheckpointTest;
GO

CREATE DATABASE CheckpointTest ON PRIMARY (
    NAME = 'CheckpointTest_data',
    FILENAME = N'D:\SQLskills\CheckpointTest_data.mdf')
LOG ON (
    NAME = 'CheckpointTest_log',
    FILENAME = N'D:\SQLskills\CheckpointTest_log.ldf',
    SIZE = 250MB,
    FILEGROWTH = 20MB);
GO

USE CheckpointTest;
GO

-- Create a table that will grow very
-- quickly and generate lots of transaction
-- log
CREATE TABLE BigRows (
	c1 INT IDENTITY,
	c2 CHAR (8000) DEFAULT 'a');
GO

-- Make sure the database is in SIMPLE
-- recovery model
ALTER DATABASE CheckpointTest SET RECOVERY SIMPLE;
GO

-- Startup perfmon with checkpoint pages/sec

-- Another window...
SET NOCOUNT ON;
GO
INSERT INTO CheckpointTest.dbo.BigRows DEFAULT VALUES;
GO 2000000


-- Trace CHECKPOINT execution
DBCC TRACEON (3605, -1);
DBCC TRACEON (3502, -1);
GO
EXEC sp_cycle_errorlog;
GO

-- Look at errorlog at background task...
EXEC xp_readerrorlog;
GO

-- Only shows start and end. What about details?
DBCC TRACEON (3504, -1);
GO

EXEC xp_readerrorlog;
GO

-- What about in the log?
SELECT * FROM fn_dblog (NULL, NULL);
GO

SELECT * FROM fn_dblog (NULL, NULL)
WHERE [Operation] LIKE '%CKPT%';
GO

SELECT * FROM fn_dblog (NULL, NULL)
WHERE [Operation] LIKE '%CKPT%'
OR [Transaction Name] LIKE 'Paul'
GO

DBCC TRACEOFF (3605, -1);
DBCC TRACEOFF (3502, -1);
DBCC TRACEOFF (3504, -1);
GO